@@ -13,7 +13,8 @@ class DNSTest(unittest.TestCase):
     def setUp(self):
         self.loop = asyncio.new_event_loop()
         self.addCleanup(self.loop.close)
-        self.resolver = aiodns.DNSResolver(loop=self.loop)
+        self.resolver = aiodns.DNSResolver(loop=self.loop, timeout=5.0)
+        self.resolver.nameservers = ['8.8.8.8']
 
     def tearDown(self):
         self.resolver = None
@@ -84,6 +85,16 @@ class DNSTest(unittest.TestCase):
     def test_query_bad_type(self):
         self.assertRaises(ValueError, self.resolver.query, 'google.com', 'XXX')
 
+    def test_query_txt_chaos(self):
+        self.resolver = aiodns.DNSResolver(loop=self.loop)
+        self.resolver.nameservers = ['1.1.1.1']
+        f = self.resolver.query('id.server', 'TXT', 'CHAOS')
+        result = self.loop.run_until_complete(f)
+        self.assertTrue(result)
+
+    def test_query_bad_class(self):
+        self.assertRaises(ValueError, self.resolver.query, 'google.com', 'A', "INVALIDCLASS")
+
     def test_query_timeout(self):
         self.resolver = aiodns.DNSResolver(timeout=0.1, loop=self.loop)
         self.resolver.nameservers = ['1.2.3.4']
@@ -147,4 +158,3 @@ class DNSTest(unittest.TestCase):
 
 if __name__ == '__main__':
     unittest.main(verbosity=2)
-
